from candlelite.calculate import bar
from candlelite.calculate import interval
from candlelite.calculate import technical
from candlelite.calculate import transform
from candlelite.calculate import valid



from candlelite import calculate
from candlelite.calculate import *

from candlelite import io
from candlelite.io import *

from candlelite import crypto
from candlelite.crypto import *

from candlelite import settings

__version__ = '1.0.5'



from candlelite.exception._base import AbstractEXP, get_error_msg


class ExecuteException(AbstractEXP):
    def __init__(self, func, msg):
        self.error_msg = get_error_msg(func=func, reason=msg)
